@@ -1,6 +1,6 @@
 import sys
 sys.path.append("../src")
-import src.main as main
+import solgraphPlus.main as main
 import os
 import pprint
 
